@@ -9,14 +9,14 @@ import tempfile
 from subprocess import Popen
 
 import jinja2
-
-from six import string_types, binary_type
-
+from six import binary_type
+from six import string_types
 from six.moves import configparser
+
 from . import macro as macro_module
+from . import __version__
 from . import utils
 from .parser import Parser
-from . import __version__
 
 BASE_DIR = os.path.dirname(__file__)
 THEMES_DIR = os.path.join(BASE_DIR, 'themes')
@@ -74,7 +74,6 @@ class Generator(object):
         self.verbose = kwargs.get('verbose', False)
         self.linenos = self.linenos_check(kwargs.get('linenos'))
         self.watch = kwargs.get('watch', False)
-        self.math_output = kwargs.get('math_output', False)
         self.num_slides = 0
         self.__toc = []
 
@@ -102,7 +101,6 @@ class Generator(object):
             self.add_user_css(config.get('css', []))
             self.add_user_js(config.get('js', []))
             self.linenos = self.linenos_check(config.get('linenos', self.linenos))
-            self.math_output = config.get('math_output', self.math_output)
         else:
             self.source = source
             self.work_dir = '.'
@@ -206,7 +204,8 @@ class Generator(object):
                 raise IOError("Direct output mode is not available for PDF "
                               "export")
             else:
-                print(self.render().encode(self.encoding))
+                out = getattr(sys.stdout, 'buffer', sys.stdout)
+                out.write(self.render().encode(self.encoding))
         else:
             self.write_and_log()
 
@@ -420,7 +419,6 @@ class Generator(object):
                 classes=slide_classes,
                 header=header,
                 level=level,
-                math_output=self.math_output,
                 presenter_notes=presenter_notes,
                 source=source_dict,
                 title=title,
@@ -451,7 +449,7 @@ class Generator(object):
                 'slides': slides, 'toc': self.toc, 'embed': self.embed,
                 'css': self.get_css(), 'js': self.get_js(),
                 'user_css': self.user_css, 'user_js': self.user_js,
-                'math_output': self.math_output, 'version': __version__}
+                'version': __version__}
 
     def linenos_check(self, value):
         """ Checks and returns a valid value for the ``linenos`` option.
@@ -476,25 +474,26 @@ class Generator(object):
             raw_config.read(config_source)
         except Exception as e:
             raise RuntimeError(u"Invalid configuration file: %s" % e)
-        config = {}
-        config['source'] = raw_config.get('landslide', 'source') \
-            .replace('\r', '').split('\n')
-        if raw_config.has_option('landslide', 'theme'):
-            config['theme'] = raw_config.get('landslide', 'theme')
+        section_name = 'landslide' if raw_config.has_section('landslide') else 'darkslide'
+        config = {
+            'source': raw_config.get(section_name, 'source').replace('\r', '').split('\n')
+        }
+        if raw_config.has_option(section_name, 'theme'):
+            config['theme'] = raw_config.get(section_name, 'theme')
             self.log(u"Using    configured theme %s" % config['theme'])
-        if raw_config.has_option('landslide', 'destination'):
-            config['destination'] = raw_config.get('landslide', 'destination')
-        if raw_config.has_option('landslide', 'linenos'):
-            config['linenos'] = raw_config.get('landslide', 'linenos')
-        for boolopt in ('embed', 'relative', 'copy_theme', 'math_output'):
-            if raw_config.has_option('landslide', boolopt):
-                config[boolopt] = raw_config.getboolean('landslide', boolopt)
-        if raw_config.has_option('landslide', 'extensions'):
-            config['extensions'] = ",".join(raw_config.get('landslide', 'extensions').replace('\r', '').split('\n'))
-        if raw_config.has_option('landslide', 'css'):
-            config['css'] = raw_config.get('landslide', 'css').replace('\r', '').split('\n')
-        if raw_config.has_option('landslide', 'js'):
-            config['js'] = raw_config.get('landslide', 'js').replace('\r', '').split('\n')
+        if raw_config.has_option(section_name, 'destination'):
+            config['destination'] = raw_config.get(section_name, 'destination')
+        if raw_config.has_option(section_name, 'linenos'):
+            config['linenos'] = raw_config.get(section_name, 'linenos')
+        for boolopt in ('embed', 'relative', 'copy_theme'):
+            if raw_config.has_option(section_name, boolopt):
+                config[boolopt] = raw_config.getboolean(section_name, boolopt)
+        if raw_config.has_option(section_name, 'extensions'):
+            config['extensions'] = ",".join(raw_config.get(section_name, 'extensions').replace('\r', '').split('\n'))
+        if raw_config.has_option(section_name, 'css'):
+            config['css'] = raw_config.get(section_name, 'css').replace('\r', '').split('\n')
+        if raw_config.has_option(section_name, 'js'):
+            config['js'] = raw_config.get(section_name, 'js').replace('\r', '').split('\n')
         return config
 
     def process_macros(self, content, source, context):
