@@ -2,12 +2,13 @@ function main() {
     // Since we don't have the fallback of attachEvent and
     // other IE only stuff we won't try to run JS for IE.
     // It will run though when using Google Chrome Frame
-    if (document.all) { return; }
+    if (document.all) {
+        return;
+    }
 
     var currentSlideNo;
     var notesOn = false;
-    var expanded = false;
-    var hiddenContext = false;
+    var hiddenNext = false;
     var blanked = false;
     var slides = document.getElementsByClassName('slide');
     var touchStartX = 0;
@@ -21,7 +22,7 @@ function main() {
     var presenterViewWin = null;
     var isPresenterView = false;
 
-    var str2array = function(s) {
+    var str2array = function (s) {
         if (typeof s == 'string' || s instanceof String) {
             if (s.indexOf(' ') < 0) {
                 a1[0] = s;
@@ -33,11 +34,11 @@ function main() {
         return s;
     };
 
-    var trim = function(str) {
+    var trim = function (str) {
         return str.replace(/^\s\s*/, '').replace(/\s\s*$/, '');
     };
 
-    var addClass = function(node, classStr) {
+    var addClass = function (node, classStr) {
         classStr = str2array(classStr);
         var cls = ' ' + node.className + ' ';
         for (var i = 0, len = classStr.length, c; i < len; ++i) {
@@ -49,7 +50,7 @@ function main() {
         node.className = trim(cls);
     };
 
-    var removeClass = function(node, classStr) {
+    var removeClass = function (node, classStr) {
         var cls;
         if (!node) {
             throw 'no node provided';
@@ -69,7 +70,7 @@ function main() {
         }
     };
 
-    var getSlideEl = function(slideNo) {
+    var getSlideEl = function (slideNo) {
         if (slideNo > 0) {
             return slides[slideNo - 1];
         } else {
@@ -77,7 +78,7 @@ function main() {
         }
     };
 
-    var getSlideTitle = function(slideNo) {
+    var getSlideTitle = function (slideNo) {
         var el = getSlideEl(slideNo);
         if (el) {
             var headers = el.getElementsByTagName('header');
@@ -88,7 +89,7 @@ function main() {
         return null;
     };
 
-    var getSlidePresenterNote = function(slideNo) {
+    var getSlidePresenterNote = function (slideNo) {
         var el = getSlideEl(slideNo);
         if (el) {
             var n = el.getElementsByClassName('presenter_notes');
@@ -99,29 +100,23 @@ function main() {
         return null;
     };
 
-    var changeSlideElClass = function(slideNo, className) {
+    var changeSlideElClass = function (slideNo, className) {
         var el = getSlideEl(slideNo);
         if (el) {
-            removeClass(el, 'far-past past current future far-future none');
+            removeClass(el, 'prev current next after_next none');
             addClass(el, className);
         }
     };
 
-    var updateSlideClasses = function(updateOther) {
+    var updateSlideClasses = function (updateOther) {
         window.location.hash = (isPresenterView ? "presenter:" : "slide:") + currentSlideNo;
 
-        for (var i=1; i<currentSlideNo-1; i++) {
-            changeSlideElClass(i, 'far-past');
-        }
-
-        changeSlideElClass(currentSlideNo - 1, 'past');
+        for (i = 1; i < currentSlideNo + 1; i++) changeSlideElClass(i, 'none');
+        changeSlideElClass(currentSlideNo - 1, 'prev');
         changeSlideElClass(currentSlideNo, 'current');
-        changeSlideElClass(currentSlideNo + 1, 'future');
-        changeSlideElClass(currentSlideNo + 2, 'far-future');
-
-        for (i=currentSlideNo+3; i<slides.length+1; i++) {
-            changeSlideElClass(i, 'none');
-        }
+        changeSlideElClass(currentSlideNo + 1, 'next');
+        changeSlideElClass(currentSlideNo + 2, 'after_next');
+        for (i = currentSlideNo + 3; i < slides.length + 1; i++) changeSlideElClass(i, 'none');
 
         highlightCurrentTocLink();
 
@@ -129,11 +124,14 @@ function main() {
 
         updatePresenterNotes();
 
-        if (updateOther) { updateOtherPage(); }
+        if (updateOther) updateOtherPage();
+        if (overviewActive) scrollToCurrent();
     };
 
-    var updatePresenterNotes = function() {
-        if (!isPresenterView) { return; }
+    var updatePresenterNotes = function () {
+        if (!isPresenterView) {
+            return;
+        }
 
         var existingNote = document.getElementById('current_presenter_notes');
         var currentNote = getSlidePresenterNote(currentSlideNo).cloneNode(true);
@@ -142,12 +140,12 @@ function main() {
         existingNote.replaceChild(currentNote, document.getElementById('presenter_note'));
     };
 
-    var highlightCurrentTocLink = function() {
+    var highlightCurrentTocLink = function () {
         var toc = document.getElementById('toc');
 
         if (toc) {
             var tocRows = toc.getElementsByTagName('tr');
-            for (var i=0; i<tocRows.length; i++) {
+            for (var i = 0; i < tocRows.length; i++) {
                 removeClass(tocRows.item(i), 'active');
             }
 
@@ -158,32 +156,44 @@ function main() {
         }
     };
 
-    var updateOtherPage = function() {
-        if (!showingPresenterView) { return; }
+    var updateOtherPage = function () {
+        if (!showingPresenterView) {
+            return;
+        }
 
         var w = isPresenterView ? window.opener : presenterViewWin;
-        w.postMessage('slide#' + currentSlideNo, '*');
+        if (w) w.postMessage('slide#' + currentSlideNo, '*');
     };
 
-    var nextSlide = function() {
+    var nextSlide = function () {
         if (currentSlideNo < slides.length) {
             currentSlideNo++;
         }
         updateSlideClasses(true);
     };
 
-    var prevSlide = function() {
+    var prevSlide = function () {
         if (currentSlideNo > 1) {
             currentSlideNo--;
         }
         updateSlideClasses(true);
     };
 
-    var showNotes = function() {
+    var firstSlide = function () {
+        currentSlideNo = 1;
+        updateSlideClasses(true);
+    };
+
+    var lastSlide = function () {
+        currentSlideNo = slides.length;
+        updateSlideClasses(true);
+    };
+
+    var showNotes = function () {
         var slide = getSlideEl(currentSlideNo),
             notes = slide.getElementsByClassName('presenter_notes');
         for (var i = 0, len = notes.length; i < len; i++) {
-            notes.item(i).style.display = (notesOn) ? 'none':'block';
+            notes.item(i).style.display = (notesOn) ? 'none' : 'block';
         }
         notesOn = !notesOn;
         if (notesOn) {
@@ -193,7 +203,7 @@ function main() {
         }
     };
 
-    var showSlideNumbers = function() {
+    var showSlideNumbers = function () {
         var asides = document.getElementsByClassName('page_number');
         var hidden = asides[0].style.display != 'block';
         for (var i = 0; i < asides.length; i++) {
@@ -201,7 +211,7 @@ function main() {
         }
     };
 
-    var showSlideSources = function() {
+    var showSlideSources = function () {
         var asides = document.getElementsByClassName('source');
         var hidden = asides[0].style.display != 'block';
         for (var i = 0; i < asides.length; i++) {
@@ -209,9 +219,9 @@ function main() {
         }
     };
 
-    var showToc = function() {
+    var showToc = function () {
         if (helpOpened) {
-                showHelp();
+            showHelp();
         }
         var toc = document.getElementById('toc');
         if (toc) {
@@ -221,9 +231,9 @@ function main() {
         updateOverview();
     };
 
-    var showHelp = function() {
+    var showHelp = function () {
         if (tocOpened) {
-                showToc();
+            showToc();
         }
 
         var help = document.getElementById('help');
@@ -234,8 +244,10 @@ function main() {
         }
     };
 
-    var showPresenterView = function() {
-        if (isPresenterView) { return; }
+    var showPresenterView = function () {
+        if (isPresenterView) {
+            return;
+        }
 
         if (showingPresenterView) {
             if (presenterViewWin)
@@ -244,27 +256,38 @@ function main() {
             showingPresenterView = false;
         } else {
             presenterViewWin = open(window.location.pathname + "#presenter:" + currentSlideNo, 'presenter_notes',
-                                    'directories=no,location=no,toolbar=no,menubar=no,copyhistory=no');
+                'directories=no,location=no,toolbar=no,menubar=no,copyhistory=no');
             showingPresenterView = true;
         }
     };
 
-    var toggleOverview = function() {
+    var toggleOverview = function () {
+        if (helpOpened) {
+            showHelp();
+            return
+        }
+        if (tocOpened) {
+            showToc();
+            return;
+        }
         if (!overviewActive) {
             addClass(document.body, 'expose');
             overviewActive = true;
-            setScale(1);
+            scrollToCurrent();
         } else {
             removeClass(document.body, 'expose');
             overviewActive = false;
-            if (expanded) {
-                setScale(scale);    // restore scale
-            }
         }
+        setScale();
         updateOverview();
     };
+    var scrollToCurrent = function () {
+        setTimeout(function () {
+            document.querySelector('.slide.current').parentElement.scrollIntoView(true);
+        });
+    }
 
-    var updateOverview = function() {
+    var updateOverview = function () {
         try {
             var presentation = document.getElementsByClassName('presentation')[0];
         } catch (e) {
@@ -291,16 +314,16 @@ function main() {
         }
     };
 
-    var computeScale = function() {
+    var computeScale = function () {
         var cSlide = document.getElementsByClassName('current')[0];
-        var sx = (cSlide.clientWidth + 20) / window.innerWidth;
+        var sx = (cSlide.clientWidth + 20) * (hiddenNext ? 2 : 1) / window.innerWidth;
         var sy = (cSlide.clientHeight + 20) / window.innerHeight;
         return 1 / Math.max(sy, sx);
     };
 
-    var setScale = function(scale) {
+    var setScale = function () {
         var presentation = document.getElementsByClassName('slides')[0];
-        var transform = 'scale(' + scale + ')';
+        var transform = 'scale(' + (overviewActive ? 1 : computeScale()) + ')';
         presentation.style.MozTransform = transform;
         presentation.style.WebkitTransform = transform;
         presentation.style.OTransform = transform;
@@ -308,47 +331,32 @@ function main() {
         presentation.style.transform = transform;
     };
 
-    var expandSlides = function() {
-        if (overviewActive) {
+    var showNext = function () {
+        var presentation = document.getElementsByClassName('slides')[0];
+        addClass(presentation, 'show_next');
+        hiddenNext = true;
+        setScale();
+    };
+
+    var hideNext = function () {
+        if (isPresenterView) {
             return;
         }
-        if (expanded) {
-            setScale(1);
-            showContext();
-            expanded = false;
-        } else {
-            setExpanded();
-        }
-    };
-    var setExpanded = function() {
-        scale = computeScale();
-        setScale(scale);
-        expanded = true;
-        hideContext();
-    };
-
-    var showContext = function() {
         var presentation = document.getElementsByClassName('slides')[0];
-        removeClass(presentation, 'nocontext');
-        hiddenContext = true;
+        removeClass(presentation, 'show_next');
+        hiddenNext = false;
+        setScale();
     };
 
-    var hideContext = function() {
-        if (isPresenterView) { return; }
-        var presentation = document.getElementsByClassName('slides')[0];
-        addClass(presentation, 'nocontext');
-        hiddenContext = false;
-    };
-
-    var toggleContext = function() {
-        if (hiddenContext) {
-            hideContext();
+    var toggleNext = function () {
+        if (hiddenNext) {
+            hideNext();
         } else {
-            showContext();
+            showNext();
         }
     };
 
-    var toggleBlank = function() {
+    var toggleBlank = function () {
         blank_elem = document.getElementById('blank');
 
         blank_elem.style.display = blanked ? 'none' : 'block';
@@ -356,7 +364,7 @@ function main() {
         blanked = !blanked;
     };
 
-    var isModifierKey = function(keyCode) {
+    var isModifierKey = function (keyCode) {
         switch (keyCode) {
             case 16: // shift
             case 17: // ctrl
@@ -370,24 +378,19 @@ function main() {
         }
     };
 
-    var checkModifierKeyUp = function(event) {
+    var checkModifierKeyUp = function (event) {
         if (isModifierKey(event.keyCode)) {
             modifierKeyDown = false;
         }
     };
 
-    var checkModifierKeyDown = function(event) {
+    var checkModifierKeyDown = function (event) {
         if (isModifierKey(event.keyCode)) {
             modifierKeyDown = true;
         }
     };
 
-    var handleBodyKeyDown = function(event) {
-        if (modifierKeyDown && event.keyCode == 80) {
-            setScale(1);
-            showContext();
-            expanded = false;
-        }
+    var handleBodyKeyDown = function (event) {
         if (modifierKeyDown) {
             return
         }
@@ -411,6 +414,12 @@ function main() {
                 event.preventDefault();
                 nextSlide();
                 break;
+            case 35: // end
+                lastSlide();
+                break;
+            case 36: // home
+                firstSlide();
+                break;
             case 50: // 2
                 showNotes();
                 break;
@@ -423,12 +432,7 @@ function main() {
                 break;
             case 67: // c
                 if (!overviewActive) {
-                    toggleContext();
-                }
-                break;
-            case 69: // e
-                if (!overviewActive) {
-                    expandSlides();
+                    toggleNext();
                 }
                 break;
             case 72: // h
@@ -455,7 +459,7 @@ function main() {
         }
     };
 
-    var handleWheel = function(event) {
+    var handleWheel = function (event) {
         if (tocOpened || helpOpened || overviewActive) {
             return;
         }
@@ -467,24 +471,24 @@ function main() {
         }
 
         if (event.wheelDelta) {
-            delta = event.wheelDelta/120;
+            delta = event.wheelDelta / 120;
             if (window.opera) delta = -delta;
         } else if (event.detail) {
-            delta = -event.detail/3;
+            delta = -event.detail / 3;
         }
 
-        if (delta && delta <0) {
+        if (delta && delta < 0) {
             nextSlide();
         } else if (delta) {
             prevSlide();
         }
     };
 
-    var addSlideClickListeners = function() {
-        for (var i=0; i < slides.length; i++) {
+    var addSlideClickListeners = function () {
+        for (var i = 0; i < slides.length; i++) {
             var slide = slides.item(i);
             slide.num = i + 1;
-            slide.addEventListener('click', function(e) {
+            slide.addEventListener('click', function (e) {
                 if (overviewActive) {
                     currentSlideNo = this.num;
                     toggleOverview();
@@ -496,37 +500,37 @@ function main() {
         }
     };
 
-    var addRemoteWindowControls = function() {
-        window.addEventListener("message", function(e) {
+    var addRemoteWindowControls = function () {
+        window.addEventListener("message", function (e) {
             if (e.data.indexOf("slide#") != -1) {
-                    currentSlideNo = Number(e.data.replace('slide#', ''));
-                    updateSlideClasses(false);
+                currentSlideNo = Number(e.data.replace('slide#', ''));
+                updateSlideClasses(false);
             }
         }, false);
     };
 
-    var addTouchListeners = function() {
-        document.addEventListener('touchstart', function(e) {
+    var addTouchListeners = function () {
+        document.addEventListener('touchstart', function (e) {
             touchStartX = e.touches[0].pageX;
         }, false);
-        document.addEventListener('touchend', function(e) {
+        document.addEventListener('touchend', function (e) {
             var pixelsMoved = touchStartX - e.changedTouches[0].pageX;
             var SWIPE_SIZE = 150;
             if (pixelsMoved > SWIPE_SIZE) {
                 nextSlide();
             }
             else if (pixelsMoved < -SWIPE_SIZE) {
-             prevSlide();
+                prevSlide();
             }
         }, false);
     };
 
-    var addTocLinksListeners = function() {
+    var addTocLinksListeners = function () {
         var toc = document.getElementById('toc');
         if (toc) {
             var tocLinks = toc.getElementsByTagName('a');
-            for (var i=0; i < tocLinks.length; i++) {
-                tocLinks.item(i).addEventListener('click', function(e) {
+            for (var i = 0; i < tocLinks.length; i++) {
+                tocLinks.item(i).addEventListener('click', function (e) {
                     currentSlideNo = Number(this.attributes['href'].value.replace('#slide:', ''));
                     updateSlideClasses(true);
                     e.preventDefault();
@@ -534,10 +538,9 @@ function main() {
             }
         }
     };
-
     // initialize
 
-    (function() {
+    (function () {
         if (window.location.hash == "") {
             currentSlideNo = 1;
         } else if (window.location.hash.indexOf("#presenter:") != -1) {
@@ -553,12 +556,12 @@ function main() {
         document.addEventListener('keyup', checkModifierKeyUp);
         document.addEventListener('keydown', handleBodyKeyDown);
         document.addEventListener('keydown', checkModifierKeyDown);
-        document.addEventListener('visibilitychange', function(event) {
+        document.addEventListener('visibilitychange', function (event) {
             if (document.hidden) {
                 modifierKeyDown = false;
             }
         }, false);
-        setInterval(function() {
+        setInterval(function () {
             if (!document.hasFocus()) {
                 modifierKeyDown = false;
             }
@@ -566,13 +569,16 @@ function main() {
 
         window.addEventListener("mousewheel", handleWheel);
         window.addEventListener("DOMMouseScroll", handleWheel);
-        window.addEventListener("DOMContentLoaded", expandSlides);
-        window.onresize = function(){
-            setScale(!overviewActive && expanded ? scale = computeScale() : 1);
+        window.addEventListener("DOMContentLoaded", function () {
+            setScale();
+            hideNext();
+        });
+        window.onresize = function () {
+            setScale();
         }
 
         for (var i = 0, el; el = slides[i]; i++) {
-            addClass(el, 'slide far-future');
+            addClass(el, 'slide');
         }
         updateSlideClasses(false);
 
